package com.yiqi.activity.service;

import java.math.BigDecimal;
import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.activity.domain.ActivityRechargeItem;
import com.yiqi.activity.domain.vo.ActivityRechargeItemVO;

/**
 * 充值多送活动Service接口
 *
 * @author xiaohei
 * @date 2023-09-10
 */
public interface IActivityRechargeItemService extends IService<ActivityRechargeItem> {
    /**
     * 查询充值多送活动
     *
     * @param id 充值多送活动主键
     * @return 充值多送活动
     */
    public ActivityRechargeItem selectActivityRechargeItemById(Long id);

    /**
     * 查询充值多送活动列表
     *
     * @param activityRechargeItem 充值多送活动
     * @return 充值多送活动集合
     */
    public List<ActivityRechargeItemVO> selectActivityRechargeItemList(ActivityRechargeItem activityRechargeItem);

    /**
     * 新增充值多送活动
     *
     * @param activityRechargeItem 充值多送活动
     * @return 结果
     */
    public int insertActivityRechargeItem(ActivityRechargeItem activityRechargeItem);

    /**
     * 修改充值多送活动
     *
     * @param activityRechargeItem 充值多送活动
     * @return 结果
     */
    public int updateActivityRechargeItem(ActivityRechargeItem activityRechargeItem);

    /**
     * 批量删除充值多送活动
     *
     * @param ids 需要删除的充值多送活动主键集合
     * @return 结果
     */
    public int deleteActivityRechargeItemByIds(Long[] ids);

    /**
     * 删除充值多送活动信息
     *
     * @param id 充值多送活动主键
     * @return 结果
     */
    public int deleteActivityRechargeItemById(Long id);


    public ActivityRechargeItem getGiveAmountByActivity(Long rechargeTypeId, Long storeId);

    List<ActivityRechargeItemVO> getRechargeActivityItemInfo(Long activityId);
}
